pg.ddx.io pgsql-committers@postgresql.org mailing list archivehelp / color / mirror / Atom feed
pgsql: Use DELETE instead of UPDATE to speed up vacuum test 3+ messages / 1 participants [nested] [flat]
* pgsql: Use DELETE instead of UPDATE to speed up vacuum test @ 2024-07-29 19:46 Melanie Plageman <melanieplageman@gmail.com> 0 siblings, 0 replies; 3+ messages in thread From: Melanie Plageman @ 2024-07-29 19:46 UTC (permalink / raw) To: pgsql-committers@lists.postgresql.org Use DELETE instead of UPDATE to speed up vacuum test 01e2b7f0fd02a44e introduced a test which generated dead tuples for vacuum with an UPDATE. The test only required enough dead TIDs for two rounds of index vacuuming. This can be accomplished with a DELETE instead of an UPDATE -- which generates about 50% less WAL and makes the test 20% faster in many cases. The test takes several seconds (more on slow buildfarm animals) because we need quite a few tuples to trigger two rounds of index vacuuming; so it is worth a follow-on commit to speed it up. Suggested-by: Masahiko Sawada Discussion: https://postgr.es/m/CAAKRu_bWmMjmqL%2BOZ2duEQ80u7cRvpsExLNZNjzk-pXX5skwMQ%40mail.gmail.com Backpatch-through: 14, the first version containing this test. Branch ------ REL_16_STABLE Details ------- https://git.postgresql.org/pg/commitdiff/571e0ee40ebdaf0c75b11756620c9c9d453cc644 Modified Files -------------- src/test/recovery/t/043_vacuum_horizon_floor.pl | 2 +- 1 file changed, 1 insertion(+), 1 deletion(-) ^ permalink raw reply [nested|flat] 3+ messages in thread
* pgsql: Use DELETE instead of UPDATE to speed up vacuum test @ 2024-07-29 19:46 Melanie Plageman <melanieplageman@gmail.com> 0 siblings, 0 replies; 3+ messages in thread From: Melanie Plageman @ 2024-07-29 19:46 UTC (permalink / raw) To: pgsql-committers@lists.postgresql.org Use DELETE instead of UPDATE to speed up vacuum test e2e992820f104def introduced a test which generated dead tuples for vacuum with an UPDATE. The test only required enough dead TIDs for two rounds of index vacuuming. This can be accomplished with a DELETE instead of an UPDATE -- which generates about 50% less WAL and makes the test 20% faster in many cases. The test takes several seconds (more on slow buildfarm animals) because we need quite a few tuples to trigger two rounds of index vacuuming; so it is worth a follow-on commit to speed it up. Suggested-by: Masahiko Sawada Discussion: https://postgr.es/m/CAAKRu_bWmMjmqL%2BOZ2duEQ80u7cRvpsExLNZNjzk-pXX5skwMQ%40mail.gmail.com Backpatch-through: 14, the first version containing this test. Branch ------ REL_15_STABLE Details ------- https://git.postgresql.org/pg/commitdiff/9744fe24118ba5738dda9008533ed00227f5d069 Modified Files -------------- src/test/recovery/t/043_vacuum_horizon_floor.pl | 2 +- 1 file changed, 1 insertion(+), 1 deletion(-) ^ permalink raw reply [nested|flat] 3+ messages in thread
* pgsql: Use DELETE instead of UPDATE to speed up vacuum test @ 2024-07-29 19:46 Melanie Plageman <melanieplageman@gmail.com> 0 siblings, 0 replies; 3+ messages in thread From: Melanie Plageman @ 2024-07-29 19:46 UTC (permalink / raw) To: pgsql-committers@lists.postgresql.org Use DELETE instead of UPDATE to speed up vacuum test d42f60ccf07d89c introduced a test which generated dead tuples for vacuum with an UPDATE. The test only required enough dead TIDs for two rounds of index vacuuming. This can be accomplished with a DELETE instead of an UPDATE -- which generates about 50% less WAL and makes the test 20% faster in many cases. The test takes several seconds (more on slow buildfarm animals) because we need quite a few tuples to trigger two rounds of index vacuuming; so it is worth a follow-on commit to speed it up. Suggested-by: Masahiko Sawada Discussion: https://postgr.es/m/CAAKRu_bWmMjmqL%2BOZ2duEQ80u7cRvpsExLNZNjzk-pXX5skwMQ%40mail.gmail.com Backpatch-through: 14, the first version containing this test. Branch ------ REL_14_STABLE Details ------- https://git.postgresql.org/pg/commitdiff/924a08b76f5d9f89b2569caed26113f0a020c644 Modified Files -------------- src/test/recovery/t/043_vacuum_horizon_floor.pl | 2 +- 1 file changed, 1 insertion(+), 1 deletion(-) ^ permalink raw reply [nested|flat] 3+ messages in thread
end of thread, other threads:[~2024-07-29 19:46 UTC | newest] Thread overview: 3+ messages (download: mbox mbox.gz follow: Atom feed) -- links below jump to the message on this page -- 2024-07-29 19:46 pgsql: Use DELETE instead of UPDATE to speed up vacuum test Melanie Plageman <melanieplageman@gmail.com> 2024-07-29 19:46 pgsql: Use DELETE instead of UPDATE to speed up vacuum test Melanie Plageman <melanieplageman@gmail.com> 2024-07-29 19:46 pgsql: Use DELETE instead of UPDATE to speed up vacuum test Melanie Plageman <melanieplageman@gmail.com>
This inbox is served by DDX for PostgreSQL; see mirroring instructions for how to clone and mirror all data and code used for this inbox